@@ -8,7 +8,7 @@ use File::Share ':all';
 use Moo;
 use namespace::clean;
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Get XML.
 has xml => (
@@ -115,6 +115,8 @@ For more information about KualaLumpur Map, click L<here|https://https://en.wiki
 
 =head1 EXAMPLE1
 
+=for comment filename=print_kuala_lumpur_route.pl
+
  use strict;
  use warnings;
 
@@ -135,6 +137,8 @@ For more information about KualaLumpur Map, click L<here|https://https://en.wiki
 
 =head1 EXAMPLE2
 
+=for comment filename=print_kuala_lumpur_def_xml_file.pl
+
  use strict;
  use warnings;
 
@@ -154,6 +158,8 @@ For more information about KualaLumpur Map, click L<here|https://https://en.wiki
 
 =head1 EXAMPLE3
 
+=for comment filename=print_kuala_lumpur_image.pl
+
  use strict;
  use warnings;
 
@@ -177,18 +183,20 @@ For more information about KualaLumpur Map, click L<here|https://https://en.wiki
  system "ls -l KualaLumpur.png";
 
  # Output like:
- # -rw-r--r-- 1 skim skim 379962 Sep 28 12:11 KualaLumpur.png
+ # -rw-r--r-- 1 skim skim 374739 23. led 18.57 KualaLumpur.png
 
 =begin html
 
-<a href="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-KualaLumpur/master/images/ex3.png">
-  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-KualaLumpur/master/images/ex3.png" alt="Rapid Rail" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-KualaLumpur/master/images/KualaLumpur.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-KualaLumpur/master/images/KualaLumpur.png" alt="Rapid Rail" width="300px" height="300px" />
 </a>
 
 =end html
 
 =head1 EXAMPLE4
 
+=for comment filename=print_kuala_lumpur_lines.pl
+
  use strict;
  use warnings;
 
@@ -216,6 +224,8 @@ For more information about KualaLumpur Map, click L<here|https://https://en.wiki
 
 =head1 EXAMPLE5
 
+=for comment filename=print_kuala_lumpur_line_stations.pl
+
  use strict;
  use warnings;
 
@@ -301,12 +311,14 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2020 Michal Josef Špaček
- Artistic License
- BSD 2-Clause License
+© 2014-2025 Michal Josef Špaček
+
+Artistic License
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
